## Ansættelseskontrakt

Mellem undertegnede

<company-name>Møller & Søn Entreprenør A/S</company-name>

Industrivej 12, st., 9640 Farsø  
CVR-nr.: 19283745 (herefter kaldet virksomheden)

og

## Rasmus Holm

Skovkanten 7, st., 7470 Karup J (herefter kaldet medarbejderen)

indgås følgende:

<start-date>
## [SECTION-IDX]. Tiltrædelse

Medarbejderen tiltræder sin ansættelse med virkning fra den 15. juli 2024.
</start-date>

<title>
## [SECTION-IDX]. Stillingsbetegnelse

Medarbejderen indtræder i stillingen som Bygningskonstruktør.
</title>

<location>
## [SECTION-IDX]. Arbejdssted

Medarbejderens primære arbejdssted er Industrivej 12, st., 4660 Store Heddinge.
</location>

## [SECTION-IDX]. Arbejdsopgaver

Medarbejderen skal varetage følgende opgaver:

- Projektstyring af byggepladser
- Koordinering med håndværkere og rådgivere
- Tilsyn med materialeleverancer

Opgaverne kan justeres efter virksomhedens behov.

<trial-period>
Der er ikke aftalt nogen prøvetid for denne ansættelse.
</trial-period>

<salary>
## [SECTION-IDX]. Løn

Den årlige bruttoløn udgør kr. 486.000 (før skat, pension og lovpligtige bidrag). Lønnen udbetales månedsvis bagud med kr. 40.500. Lønnen overføres til medarbejderens valgte konto sidste hverdag i måneden.
</salary>

<pension>
## [SECTION-IDX]. Pension

Virksomheden indbetaler 10% og medarbejderen selv 4% af den pensionsgivende løn til pensionsordningen via PensionDanmark.
</pension>

<social-security>
## [SECTION-IDX]. Sociale sikringsbidrag

Virksomheden indbetaler alle lovpligtige sociale sikringsbidrag i henhold til gældende dansk lovgivning, herunder ATP, barselsfond samt øvrige relevante bidrag.
</social-security>

<work-time>
## [SECTION-IDX]. Arbejdstid

Den ugentlige gennemsnitlige arbejdstid udgør 37 timer. Arbejdsugen tilrettelægges hovedsageligt mandag til fredag indenfor virksomhedens normale arbejdstider.  
Lønnen er fastsat med henblik på, at nødvendigt merarbejde kan forekomme uden ekstra kompensering, medmindre andet aftales særskilt.
</work-time>

<holiday>
## [SECTION-IDX]. Ferie

Medarbejderen har ret til ferie i henhold til ferieloven, med løn under ferie.

Særligt ferietillæg udbetales i overensstemmelse med ferieloven.

Juleaftensdag og nytårsaftensdag er fridage med fuld løn.
</holiday>

<extra-holiday>
## [SECTION-IDX]. Ekstra ferie

Medarbejderen får tildelt yderligere 1 uges feriefridage årligt, svarende til 5 dage ud over ferielovens bestemmelser. Disse dage afholdes efter aftale og følger ferielovens regler for øvrig ferie.
</extra-holiday>

<training>
## [SECTION-IDX]. Efteruddannelse

Medarbejderen har ret til relevant efter- og videreuddannelse i det omfang, det er nødvendigt for varetagelsen af funktionen og efter nærmere aftale med virksomheden.
</training>

<illness>
## [SECTION-IDX]. Sygdom

Ved sygdom skal sygemelding ske til virksomheden så hurtigt som muligt samme dag. Ved langvarig sygdom kan virksomheden forlange dokumentation i form af lægeerklæring, som virksomheden betaler.

Medarbejderen har ret til sædvanlig løn under sygdom.
</illness>

<parental-leave>
## [SECTION-IDX]. Barsel og forældreorlov

Medarbejderen har ret til fravær i forbindelse med graviditet, fødsel og adoption i overensstemmelse med barsellovens regler.

Moderen har ret til fuld løn under følgende perioder:

- 4 uger før forventet fødsel
- 14 uger efter fødslen

Faderen/medmoderen har ret til fuld løn i 2 uger efter barnets fødsel.

Derudover gives ret til frihed med løn i op til 2 dage ved barns sygdom.
</parental-leave>

<termination>
## [SECTION-IDX]. Opsigelse

Ansættelsesforholdet kan fra begge parters side opsiges med 30 dages varsel til fratræden ved udgangen af en måned, medmindre funktionærlovens eller overenskomstens bestemmelser giver medarbejderen bedre rettigheder.

Opsigelsen skal ske skriftligt og være modtaget af modparten senest den sidste dag i måneden.
</termination>

<collective-agreement>
## [SECTION-IDX]. Overenskomst

Ansættelsesforholdet er omfattet af overenskomsten mellem DI Byggeri og de relevante fagforeninger.
</collective-agreement>

## [SECTION-IDX]. Tavshedspligt

Medarbejderen har tavshedspligt om virksomhedens forretningsmæssige forhold, både under og efter ansættelsen, jf. gældende lov om forretningshemmeligheder.

## [SECTION-IDX]. Retsgrundlag

Ansættelsesforholdet er reguleret af dansk ret, herunder funktionær- og ferieloven, i det omfang ovenstående ikke stiller medarbejderen bedre.

Industrivej 12, st., 9640 Farsø, den 8. juli 2024

Medarbejderen ____________________________________

Virksomheden ____________________________________